% Script: PlotHazCurve_AllPoE.m
% Plot Hazard Curve from EFEHR portal with Quantiles
%
% Copyright (C) by J. Woessner
% 12.08.2013
% j.woessner@sed.ethz.ch
%
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179

%% Set Path
sPath=pwd;
addpath(genpath(sPath))

% Define coordinate and IMT
fLon = 0.39;
fLat=46.27;
sIMT='SA';
fPoE = 0.5;
fPeriod = 50;
sSoilType = 'rock';
sAggregationType = 'arithmetic';
fAggLevel = 0.5;

% Get data from database
[vPeriod, vAcc05,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
fPoE = 0.39;
[vPeriod, vAcc039,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
fPoE = 0.1;
[vPeriod, vAcc01,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
fPoE = 0.05;
[vPeriod, vAcc005,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
fPoE = 0.02;
[vPeriod, vAcc002,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
fPoE = 0.01;
[vPeriod, vAcc001,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);

% Prepare plot
vPeriod = str2num(vPeriod);
vPeriod = vPeriod';
vAcc05=str2num(vAcc05)';
vAcc039=str2num(vAcc039)';
vAcc01=str2num(vAcc01)';
vAcc005=str2num(vAcc005)';
vAcc002=str2num(vAcc002)';
vAcc001=str2num(vAcc001)';
vLoc = str2num(sLoc);


% Plot UHS for all available periods
figure
semilogy(vPeriod,vAcc05,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0 0 0],'MarkerFaceColor',[0.5 0.5 0.5])
hold on
semilogy(vPeriod,vAcc039,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0.7 0.7 0],'MarkerFaceColor',[0.5 0.5 0.5])
semilogy(vPeriod,vAcc01,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0.8 0 0],'MarkerFaceColor',[0.5 0.5 0.5])
semilogy(vPeriod,vAcc005,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0 0.8 0],'MarkerFaceColor',[0.5 0.5 0.5])
semilogy(vPeriod,vAcc002,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0 0 0.8],'MarkerFaceColor',[0.5 0.5 0.5])
semilogy(vPeriod,vAcc001,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5])
legend('PoE: 50% in 50y','PoE: 39% in 50y','PoE: 10% in 50y','PoE: 5% in 50y','PoE: 2% in 50y','PoE: 1% in 50y')
xlabel('Period / [s]','Fontsize',12,'Fontweight','bold')
ylabel('Spectral Acceleration / [g]','Fontsize',12,'Fontweight','bold')
sText = ['Location: Lon=' num2str(roundn(vLoc(1,1),-2)) ', Lat=' num2str(roundn(vLoc(1,2),-2)) ];
text(0.2,0.00015,sText,'Fontsize',10,'Fontweight','bold')
ylim([0.0001 1])
grid on
box on

% Print
sString = ['UHS_AllPeriods_Location_' num2str(fLon) '_' num2str(fLat) '.eps'];
print('-depsc',sString)

