%% Script: PlotUHS_PoEUncertainty_SHAREexamples.m
% Plot UHS from EFEHR portal with Quantiles
%
% Copyright (C) by J. Woessner
% 20.08.2013
% j.woessner@sed.ethz.ch
%
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179

%% Set Path
sPath=pwd;
addpath(genpath(sPath))

%% Define coordinate and IMT --- Only change this part
mXY = [7.3821339 47.5; 13.3821339 42.3; 6.8821339 50.9; 27.9821339 36.2; 28.9821339 41; 22.7821339 40.8; -9.2178661 38.7; 5.2821339 60.3];
sName = {'Basel'; 'L''Aquila'; 'Cologne'; 'Rhodes'; 'Istanbul'; 'Thessaloniki'; 'Lisbon'; 'Bergen'}

% Loop over cities
for n=1:length(mXY(:,1))
    fLon = mXY(n,1);
    fLat=mXY(n,2);
    sCity = char(sName(n));
    sIMT='SA';
    fPoE = 0.1;
    fPeriod = 50;
    sSoilType = 'rock';
    
    % NO CHANGE BELOW NEEDED
    %% Set path
    sPath=pwd;
    addpath(genpath(sPath))
    
    %% Get data from database
    sAggregationType = 'ordinal';
    fAggLevel = 0.05;
    [vPeriod, vAcc05,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
    fAggLevel = 0.15;
    [vPeriod, vAcc015,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
    sAggregationType = 'arithmetic';
    fAggLevel = 0.5;
    [vPeriod, vAcc050,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
    sAggregationType = 'ordinal';
    fAggLevel = 0.85;
    [vPeriod, vAcc085,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
    fAggLevel = 0.95;
    [vPeriod, vAcc095,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);
    
    % Prepare plot data
    vPeriod = str2num(vPeriod);
    vPeriod = vPeriod';
    vAcc05=str2num(vAcc05)';
    vAcc015=str2num(vAcc015)';
    vAcc050=str2num(vAcc050)';
    vAcc085=str2num(vAcc085)';
    vAcc095=str2num(vAcc095)';
    vLoc = str2num(sLoc);
    
    %% Plot UHS for all available periods
    figure
    semilogy(vPeriod,vAcc05,'Linestyle','--','Linewidth',1.5,'Color',[0.8 0. 0])
    hold on
    semilogy(vPeriod,vAcc015,'Linestyle','--','Linewidth',1.5,'Color',[0. 0.8 0])
    semilogy(vPeriod,vAcc050,'Linestyle','-','Marker','o','Markersize',5,'Linewidth',2,'Color',[0 0 0])
    semilogy(vPeriod,vAcc085,'Linestyle','--','Linewidth',1.5,'Color',[0 0.8 0])
    semilogy(vPeriod,vAcc095,'Linestyle','--','Linewidth',1.5,'Color',[0.8 0  0])
    legend('5% Quantile','15% Quantile','Mean','85% Quantile','95% Quantile')
    
    xlabel('Period / [s]','Fontsize',12,'Fontweight','bold')
    ylabel('Spectral Acceleration / [g]','Fontsize',12,'Fontweight','bold')
    sText = ['Location: Lon=' num2str(roundn(vLoc(1,1),-2)) ', Lat=' num2str(roundn(vLoc(1,2),-2)) ];
    text(0.2,0.0015,sText,'Fontsize',10,'Fontweight','bold')
    sTitle = [sCity ': ' num2str(fPoE*100) '% Exceedance Prob. in 50y']
    title(sTitle,'Fontsize',12,'Fontweight','bold');
    ylim([0.0008 1.5])
    grid on
    box on
    
    %% Print
    sString = [sCity '_UHS_Uncertainty_PoE_' num2str(fPoE) 'in50y_Location_' num2str(fLon) '_' num2str(fLat) '.eps'];
    print('-depsc',sString)
end

